Learn R Programming

corrgrapher (version 1.0.4)

knit_print.corrgrapher: Knitr S3 method

Description

This method allows corrgrapher objects to be displayed nicely in knitr/rmarkdown documents.

Usage

# S3 method for corrgrapher
knit_print(x, ...)

Arguments

x

An object of corrgrapher class. See corrgrapher function.

...

Other parameters, passed directly to knit_print.shiny.tag

Value

2 objects will be displayed: graph of correlations on the left and a plot on the right. If x was created from explainer, the plot will visualize partial dependency of the currently selected variable. In other case, the plot will visualize distribution of the variable.