Learn R Programming

corrgrapher (version 1.0.4)

print.corrgrapher: Print S3 method

Description

This method allows corrgrapher objects to be displayed nicely in RStudio viewer.

Usage

# S3 method for corrgrapher
print(x, ...)

Arguments

x

An object of corrgrapher class. See corrgrapher function.

...

Other parameters, passed directly to save_to_html function. If x was created from explainer, the plot will visualize partial dependency of the currently selected variable. In other case, the plot will visualize distribution of the variable.