This method allows corrgrapher objects to be displayed nicely in RStudio viewer.
# S3 method for corrgrapher
print(x, ...)An object of corrgrapher class. See corrgrapher function.
Other parameters, passed directly to save_to_html function.
If x was created from explainer, the plot will visualize partial dependency
of the currently selected variable.
In other case, the plot will visualize distribution of the variable.